<?php
/* wppa-admin.php
* Package: wp-photo-album-plus
*
* Contains the admin menu and startups the admin pages
* Version 8.2.05.001
*
*/

if ( ! defined( 'ABSPATH' ) ) die( "Can't load this file directly (2)" );

/* CHECK INSTALLATION */
// Check setup
add_action ( 'init', 'wppa_setup', '8' );	// admin_init

/* ADMIN MENU */
add_action( 'admin_menu', 'wppa_add_admin' );

function wppa_add_admin() {
	global $wp_roles;
	global $wpdb;

	// Make sure admin has access rights
	if ( wppa_user_is_admin() ) {
		$wp_roles->add_cap( 'administrator', 'wppa_admin' );
		$wp_roles->add_cap( 'administrator', 'wppa_upload' );
		$wp_roles->add_cap( 'administrator', 'wppa_import' );
		$wp_roles->add_cap( 'administrator', 'wppa_moderate' );
		$wp_roles->add_cap( 'administrator', 'wppa_export' );
		$wp_roles->add_cap( 'administrator', 'wppa_settings' );
		$wp_roles->add_cap( 'administrator', 'wppa_comments' );
		$wp_roles->add_cap( 'administrator', 'wppa_edit_tags' );
		$wp_roles->add_cap( 'administrator', 'wppa_edit_sequence' );
		$wp_roles->add_cap( 'administrator', 'wppa_help' );
	}

	// See if there are comments pending moderation
	$com_pending = '';
	$com_pending_count = $wpdb->get_var( "SELECT COUNT(*) FROM $wpdb->wppa_comments WHERE status = 'pending' OR status = 'spam' OR status = ''" );
	if ( $com_pending_count ) $com_pending = '<span class="update-plugins"><span class="plugin-count">'.$com_pending_count.'</span></span>';

	// See if there are uploads pending moderation
	$upl_pending = '';
	$upl_pending_count = $wpdb->get_var( "SELECT COUNT(*) FROM $wpdb->wppa_photos WHERE status = 'pending' AND album > 0" );
	if ( $upl_pending_count ) $upl_pending = '<span class="update-plugins"><span class="plugin-count">'.$upl_pending_count.'</span></span>';

	// Compute total pending moderation
	$tot_pending = '';
	$tot_pending_count = '0';
	if ( current_user_can('wppa_comments') || current_user_can('wppa_moderate') ) $tot_pending_count += $com_pending_count;
	if ( current_user_can('wppa_admin') || current_user_can('wppa_moderate') ) $tot_pending_count+= $upl_pending_count;
	if ( $tot_pending_count ) $tot_pending = '<span class="update-plugins"><span class="plugin-count">'.'<b>'.$tot_pending_count.'</b>'.'</span></span>';

	$icon_url = WPPA_URL . '/img/camera16.png';

	// 				page_title        menu_title                                      capability    menu_slug          function      icon_url    position
	add_menu_page( 'WP Photo Album', __('Photo&thinsp;Albums', 'wp-photo-album-plus' ).$tot_pending, 'wppa_admin', 'wppa_admin_menu', 'wppa_admin', $icon_url ); //,'10' );

	//                 parent_slug        page_title                             			menu_title                             					capability            menu_slug               function
	add_submenu_page( 'wppa_admin_menu',  __('Album Admin', 'wp-photo-album-plus' ),			 	__('Album Admin', 'wp-photo-album-plus' ).$upl_pending,'wppa_admin',        	'wppa_admin_menu',      'wppa_admin' );
    add_submenu_page( 'wppa_admin_menu',  __('Upload Photos', 'wp-photo-album-plus' ),           __('Upload Photos', 'wp-photo-album-plus' ),          'wppa_upload',        	'wppa_upload_photos',   'wppa_page_upload' );
	// Uploader without album admin rights, but when the upload_edit switch set, may edit his own photos
	if ( ! current_user_can('wppa_admin') && wppa_opt( 'upload_edit') != '-none-' ) {
		add_submenu_page( 'wppa_admin_menu',  __('Edit Photos', 'wp-photo-album-plus' ), 		 __('Edit Photos', 'wp-photo-album-plus' ), 		   'wppa_upload', 		 	'wppa_edit_photo', 	 'wppa_edit_photo' );
	}
	add_submenu_page( 'wppa_admin_menu',  __('Import Photos', 'wp-photo-album-plus' ),           __('Import Photos', 'wp-photo-album-plus' ),          'wppa_import',        'wppa_import_photos',   'wppa_page_import' );
	add_submenu_page( 'wppa_admin_menu',  __('Moderate Photos', 'wp-photo-album-plus' ),		 	__('Moderate Photos', 'wp-photo-album-plus' ).(wppa_switch('moderate_bulk')?$upl_pending:$tot_pending), 'wppa_moderate', 	 'wppa_moderate_photos', 'wppa_page_moderate' );
	add_submenu_page( 'wppa_admin_menu',  __('Export Photos', 'wp-photo-album-plus' ),           __('Export Photos', 'wp-photo-album-plus' ),          'wppa_export',     	'wppa_export_photos',   'wppa_page_export' );
    add_submenu_page( 'wppa_admin_menu',  __('Settings', 'wp-photo-album-plus' ),                __('Settings', 'wp-photo-album-plus' ),               'wppa_settings',      	'wppa_options',         'wppa_page_options' );
	if ( wppa_switch( 'show_comments' ) ) {
		add_submenu_page( 'wppa_admin_menu',  __('Manage comments', 'wp-photo-album-plus' ),         __('Comments', 'wp-photo-album-plus' ).$com_pending,  'wppa_comments',      	'wppa_manage_comments', 'wppa_comment_admin' );
	}
	if ( wppa_switch( 'opt_menu_search' ) ) {
		add_submenu_page( 'wppa_admin_menu',  __('Search', 'wp-photo-album-plus' ), 					__('Search', 'wp-photo-album-plus' ), 				 'wppa_admin', 		'wppa_search',			'wppa_search' );
	}
	if ( wppa_switch( 'opt_menu_edit_tags' ) ) {
		add_submenu_page( 'wppa_admin_menu', __('Edit tags', 'wp-photo-album-plus' ), 				__('Edit tags', 'wp-photo-album-plus' ), 'wppa_edit_tags', 'wppa_edit_tags',  'wppa_tag_editor' );
	}
	if ( wppa_switch( 'opt_menu_edit_sequence' ) ) {
		add_submenu_page( 'wppa_admin_menu', __('Edit Photo Sequence', 'wp-photo-album-plus' ), 		__('Edit Photo Sequence', 'wp-photo-album-plus' ), 		'wppa_edit_sequence', 	'wppa_edit_sequence', 	'wppa_edit_sequence' );
	}
	if ( wppa_switch( 'opt_menu_doc' ) ) {
		add_submenu_page( 'wppa_admin_menu',  __('Help &amp; Info', 'wp-photo-album-plus' ),         __('Documentation', 'wp-photo-album-plus' ),        	'wppa_help',          	'wppa_help',            'wppa_page_help' );
	}
	if ( wppa_switch( 'logfile_on_menu' ) ) {
		add_submenu_page( 'wppa_admin_menu',  __('Logfile', 'wp-photo-album-plus' ), 			__('Logfile', 'wp-photo-album-plus' ), 				'administrator',  	 	'wppa_log', 			'wppa_log_page' );
	}
	$hits = get_option( 'wppa_cache_hits', '0' );
	$miss = get_option( 'wppa_cache_misses', '1' );
	$perc = sprintf( '%5.2f', 100 * $hits / ( $hits + $miss ) );
	add_submenu_page( 'wppa_admin_menu', __('Cache', 'wp-photo-album-plus' ), 					__('Cache', 'wp-photo-album-plus' ).' '. $perc . '%', 			'wppa_admin',			'wppa_cache', 	'wppa_page_cache' );
}

/* ADMIN STYLES */
add_action( 'admin_init', 'wppa_admin_styles' );

function wppa_admin_styles() {
global $wppa_api_version;

	$ver = filemtime( WPPA_PATH . '/wppa-admin-styles.css' );
	wp_register_style( 'wppa_admin_style', WPPA_URL.'/wppa-admin-styles.css', '', $ver );
	wp_enqueue_style( 'wppa_admin_style' );

	if ( wppa_can_magick() ) {
		wp_register_style( 'wppa_cropper_style', WPPA_URL.'/vendor/cropperjs/dist/cropper.min.css' );
		wp_enqueue_style( 'wppa_cropper_style' );
	}

	// Standard wppa frontend styles
	wp_register_style('wppa_style', WPPA_URL.'/wppa-style.css', array(), $wppa_api_version);
	wp_enqueue_style('wppa_style');

	$the_css = wppa_create_wppa_dynamic_css();
	wp_add_inline_style( 'wppa_style', $the_css );

	$the_css = '
	.wppa-toplevel-details > summary::before {
        content: "' . __( 'Show', 'wp-photo-album-plus' ) . '";
    }
    .wppa-toplevel-details[open] > summary::before {
        content: "' . __( 'Hide', 'wp-photo-album-plus' ) . '";
    }';
	wp_add_inline_style( 'wppa_style', $the_css );
}

// Standard theme styles, optional
add_action( 'admin_enqueue_scripts', 'theme_styles_for_wppa' );

function theme_styles_for_wppa() {

    if ( wppa_switch( 'admin_theme_css' ) ) {

		// Load theme css
		wp_enqueue_style( 'parent-style-for-wppa', get_template_directory_uri() . '/style.css', array( 'wppa_style' ) );

		// Load child theme css
		wp_enqueue_style( 'child-style-for-wppa', get_stylesheet_uri(), array( 'parent-style-for-wppa', 'wppa_style' ) );
	}

	$the_url = wppa_opt( 'admin_extra_css' );
	if ( $the_url ) {

		// Load extra stylesheet
		wp_enqueue_style( 'extra-style-for-wppa', $the_url, array( 'wppa_style' ) );
	}

	$the_css = wppa_opt( 'admin_inline_css' );
	if ( $the_css ) {

		// Load inline css
		wp_add_inline_style( wppa_switch( 'admin_theme_css' ) ? 'child-style-for-wppa' : 'wppa_style', $the_css );
	}
}

/* ADMIN SCRIPTS */
add_action( 'admin_init', 'wppa_admin_scripts' );

function wppa_admin_scripts() {
global $wppa_api_version;

	$depts = array(
		'jquery',
		'jquery-ui-sortable',
		'jquery-ui-dialog',
		'jquery-form',
		'jquery-masonry',
	);

	if ( wppa_is_file( WPPA_PATH.'/js/wppa-admin-scripts.min.js' ) ) {
		$js_ver = date( "ymd-Gis", filemtime( WPPA_PATH.'/js/wppa-admin-scripts.min.js' ) );
		wp_enqueue_script( 'wppa-admin', WPPA_URL.'/js/wppa-admin-scripts.min.js', $depts, $js_ver, true );
	}
	else {
		$js_ver = date( "ymd-Gis", filemtime( WPPA_PATH.'/js/wppa-admin-scripts.js' ) );
		wp_enqueue_script( 'wppa-admin', WPPA_URL.'/js/wppa-admin-scripts.js', $depts, $js_ver, true );
	}
 	wp_enqueue_script( 'wppa-upload', WPPA_URL.'/js/wppa-multifile-compressed.js', '', $wppa_api_version, true );
	wp_enqueue_script( 'wppa-utils', WPPA_URL . '/js/wppa-utils.js',$depts, $wppa_api_version );
 	wp_enqueue_script( 'wppa', WPPA_URL . '/js/wppa.js', $depts, $wppa_api_version );
	wp_enqueue_script( 'wppa-slideshow', WPPA_URL . '/js/wppa-slideshow.js', $depts, $wppa_api_version );
 	wp_enqueue_script( 'wppa-ajax-front', WPPA_URL . '/js/wppa-ajax-front.js', $depts, $wppa_api_version );
	wp_enqueue_script( 'wppa-zoom', WPPA_URL . '/js/wppa-zoom.js', $depts, $wppa_api_version );
	wp_enqueue_script( 'wppa-spheric', WPPA_URL . '/js/wppa-spheric.js', $depts, $wppa_api_version );
	wp_enqueue_script( 'wppa-three', WPPA_URL . '/vendor/three/three.min.js', $depts, $wppa_api_version );
	if ( wppa_can_magick() ) {
		wp_enqueue_script( 'cropperjs', WPPA_URL . '/vendor/cropperjs/dist/cropper.min.js', $depts, $wppa_api_version );
	}

	wp_enqueue_style( 'wp-jquery-ui-dialog' );
	wp_enqueue_script( 'wppa-touch-punch', '/wp-includes/js/jquery/jquery.ui.touch-punch.js' );
}

/* ADMIN PAGE PHP's */

// Album admin page
function wppa_admin() {
	wppa_grant_albums();
	require_once 'wppa-album-admin-autosave.php';
	require_once 'wppa-photo-admin-autosave.php';
	require_once 'wppa-album-covers.php';
	wppa_publish_scheduled();
	_wppa_admin();
}
// Upload admin page
function wppa_page_upload() {
	if ( wppa_is_user_blacklisted() ) wp_die(__( 'Uploading is temporary disabled for you' , 'wp-photo-album-plus' ) );
	wppa_grant_albums();
	require_once 'wppa-upload.php';
	_wppa_page_upload();
}
// Edit photo(s)
function wppa_edit_photo() {
	if ( wppa_is_user_blacklisted() ) wp_die(__( 'Editing is temporary disabled for you' , 'wp-photo-album-plus' ) );
	require_once 'wppa-photo-admin-autosave.php';
	wppa_publish_scheduled();
	_wppa_edit_photo();
}
// Import admin page
function wppa_page_import() {

	// check the user depot directory
	$dir = WPPA_DEPOT_PATH;
	if ( ! wppa_is_dir( $dir ) ) {
		wppa_mktree( $dir );
	}
	wppa_chmod( $dir, true );

	if ( wppa_is_user_blacklisted() ) wp_die(__( 'Importing is temporary disabled for you' , 'wp-photo-album-plus' ) );
	wppa_grant_albums();
	wppa_rename_files_sanitized( WPPA_DEPOT_PATH );
	require_once 'wppa-import.php';
	_wppa_page_import();
}
// Moderate admin page
function wppa_page_moderate() {
	require_once 'wppa-photo-admin-autosave.php';
	wppa_publish_scheduled();
	_wppa_moderate_photos();
}
// Export admin page
function wppa_page_export() {
	require_once 'wppa-export.php';
	_wppa_page_export();
}
// Settings admin page
function wppa_page_options() {
	require_once 'wppa-settings-autosave.php';
	require_once 'wppa-setting-functions.php';

	// jQuery Easing for Nicescroller
	$easing_url = WPPA_URL . '/vendor/jquery-easing/jquery.easing.min.js';
	wp_enqueue_script( 'nicescrollr-easing-min-js', $easing_url, array( 'jquery' ), 'all', true );

	// Nicescroll Library
	$nice_url = WPPA_URL . '/vendor/nicescroll/jquery.nicescroll.min.js';
	wp_enqueue_script( 'nicescrollr-inc-nicescroll-min-js', $nice_url, array( 'jquery', 'nicescrollr-easing-min-js' ), 'all', true );

	_wppa_page_options();
}
// Comments admin page
function wppa_comment_admin() {
	require_once 'wppa-comment-admin.php';
	_wppa_comment_admin();
}
// Search
function wppa_search() {
//	wppa_grant_albums();
	require_once 'wppa-album-admin-autosave.php';
	require_once 'wppa-photo-admin-autosave.php';
//	require_once 'wppa-album-covers.php';
	wppa_publish_scheduled();
	_wppa_search();
}
// Help admin page
function wppa_page_help() {
	require_once 'wppa-help.php';
	_wppa_page_help();
}

// Edit tags
function wppa_tag_editor() {
	require_once 'wppa-edit-tags.php';
	_wppa_edit_tags();
}

// Edit sequence
function wppa_edit_sequence() {
	require_once 'wppa-edit-sequence.php';
	require_once 'wppa-photo-admin-autosave.php';
	_wppa_edit_sequence();
}

/* GENERAL ADMIN */

// General purpose admin functions
require_once 'wppa-admin-functions.php';

if ( ! isset( $_REQUEST['page'] ) || ( $_REQUEST['page'] != 'wppa_options' && $_REQUEST['page'] != 'wppa_admin_menu' ) ) {

	require_once 'wppa-tinymce-shortcodes.php';
	require_once 'wppa-tinymce-photo.php';
}

if ( strpos( $_SERVER['REQUEST_URI'], 'widgets' ) === false ) {
	require_once 'wppa-gutenberg-photo.php';
	require_once 'wppa-gutenberg-wppa.php';
}

require_once 'wppa-privacy-policy.php';

/* This is for the changelog text when an update is available */
global $pagenow;
if ( 'plugins.php' === $pagenow )
{
    // Changelog update message
    $file   = basename( __FILE__ );
    $folder = basename( dirname( __FILE__ ) );
    $hook = "in_plugin_update_message-{$folder}/{$file}";
    add_action( $hook, 'wppa_update_message_cb', 20, 2 ); // hook for function below
}
function wppa_update_message_cb( $plugin_data, $r )
{
    $output = '<span style="margin-left:10px;color:#FF0000;">Please Read the ' .
		'<a href="http://wppa.opajaap.nl/changelog/" target="_blank" >Changelog</a>' .
		' Details Before Upgrading.</span>';

    return print $output;
}


/* Add "donate" link to main plugins page */
add_filter('plugin_row_meta', 'wppa_donate_link', 10, 2);

/* Check multisite config */
add_action('admin_notices', 'wppa_verify_multisite_config');

/* Check for pending maintenance procs */
add_action('admin_notices', 'wppa_maintenance_messages');

// Check for configuration conflicts
add_action( 'admin_notices', 'wppa_check_config_conflicts' );

// Check for dangerous upload possibilities
add_action( 'admin_notices', 'wppa_check_upload_logout' );

// Check if tags system needs conversion
add_action( 'admin_init', 'wppa_check_tag_system' );

// Check if cats system needs conversion
add_action( 'admin_init', 'wppa_check_cat_system' );

require_once 'wppa-dashboard-widgets.php';

// Load panoama js if needed at the backend
if ( wppa_get_option( 'wppa_enable_panorama' ) == 'yes' ) {
	add_action( 'admin_footer', 'wppa_load_panorama_js' );
}
function wppa_load_panorama_js() {
global $wppa_api_version;

	if ( wppa( 'has_panorama' ) ) {
		$three_url = WPPA_URL . '/vendor/three/three.min.js';
		$ver = '122';
		wp_enqueue_script( 'wppa-three-min-js', $three_url, array(), $ver, true );
	}
}

// Register category for Gutenberg
function wppa_block_categories( $categories, $post ) {

    return array_merge(
        $categories,
        array(
            array(
                'slug' => 'wppa-shortcodes',
                'title' => __( 'WPPA shortcodes', 'wp-photo-album-plus' ),
            ),
        )
    );
}
add_filter( 'block_categories_all', 'wppa_block_categories', 10, 2 );

// Fix Gutenberg bug and clear cache selectively
function wppa_fix_gutenberg_shortcodes( $id, $post, $update ) {

	// Get content
	$post_content = $post->post_content;

	// Fix block type
	$new_content = str_replace( array( 'wp:wppa/gutenberg-photo', 'wp:wppa/gutenberg-wppa' ), 'wp:shortcode', $post_content );

	// Fix virtual identifiers
	if ( strpos( $post_content, '[wppa' ) !== false ) {

		$from = ['@topten', '@lasten', '@featen', '@comten', '@tags', '@cat', '@owner', '@upldr', '@all', '@last', '@owner', '@cat', '@all', '@potd', '@last'];
		$to   = ['#topten', '#lasten', '#featen', '#comten', '#tags', '#cat', '#owner', '#upldr', '#all', '#last', '#owner', '#cat', '#all', '#potd', '#last'];
		$temp = explode( '[wppa ', $new_content );
		if ( is_array( $temp ) ) {
			foreach( array_keys( $temp ) as $key ) {
				$t = explode( ']', $temp[$key] );
				$t[0] = str_replace( $from, $to, $t[0] );
				$temp[$key] = implode( ']', $t );
			}
			$new_content = implode( '[wppa ', $temp );
		}
	}

	// Update if something changed
	if ( $post_content != $new_content ) {

		$post->post_content = $new_content;
		$iret = wp_update_post( $post );
	}

	// Clear cache for this post
	wppa_clear_cache( ['page' => $id] );

}
add_action( 'save_post', 'wppa_fix_gutenberg_shortcodes', 10, 3 );
